========
falstart
========

.. image:: https://img.shields.io/travis/Samael500/falstart.svg?maxAge=2592000&style=flat
    :target: https://travis-ci.org/Samael500/falstart
    :alt: build status

.. image:: https://img.shields.io/pypi/v/falstart.svg?maxAge=2592000&style=flat
    :target: https://pypi.python.org/pypi/falstart
    :alt: pypi version

.. image:: https://img.shields.io/pypi/status/falstart.svg?maxAge=2592000?style=flat
    :target: https://pypi.python.org/pypi/falstart
    :alt: version status

.. image:: https://img.shields.io/pypi/format/falstart.svg?maxAge=2592000?style=flat
    :target: https://pypi.python.org/pypi/falstart
    :alt: pypi format

.. image:: https://img.shields.io/pypi/implementation/falstart.svg?maxAge=2592000?style=flat
    :target: https://pypi.python.org/pypi/falstart
    :alt: python implementation

.. image:: https://img.shields.io/pypi/dm/falstart.svg?maxAge=2592000?style=flat
    :target: https://pypi.python.org/pypi/falstart
    :alt: pypi downloads

.. image:: https://img.shields.io/github/license/samael500/falstart.svg?maxAge=2592000&style=flat
    :target: https://github.com/Samael500/falstart/blob/master/LICENSE
    :alt: license

.. image:: https://img.shields.io/github/issues/samael500/falstart.svg?maxAge=2592000?style=flat
    :target: https://github.com/Samael500/falstart/issues
    :alt: issues


fast start develop box template

Pre Requirements
----------------

- Vagrant_ && VirtualBox_
- Fabric_

Setup
-----

.. code-block:: shell

    $ pip install falstart


Usage
-----

.. code-block:: shell

    $ cd /your/proj/parent/dir
    $ falstart awesomeprojname

Example project result `github.com:Samael500/falstart-example`_

.. image:: https://raw.githubusercontent.com/samael500/falstart/master/example.gif

.. _Vagrant: https://www.vagrantup.com/downloads.html
.. _VirtualBox: https://www.virtualbox.org/wiki/Downloads
.. _Fabric: https://github.com/fabric/fabric
.. _`github.com:Samael500/falstart-example`: https://github.com/Samael500/falstart-example
